# XiXiang 熙香点餐
[![PyPI](https://img.shields.io/pypi/v/xixiang.svg)](https://pypi.python.org/pypi/xixiang)

**熙香点餐非官方库**

公司打算从[美餐](https://github.com/hui-z/meican)换到熙香点餐，
于是自动点餐脚本也要加上熙香啦。

License 就是宽松的 MIT 协议，欢迎各种 Fork + PR.
